@@ -44,6 +44,7 @@ setMethod("summary", signature(object = "bdpnormal"), function(object){
   mu0_c               <- object$args1$mu0_c
   sigma0_c            <- object$args1$sigma0_c
   N0_c                <- object$args1$N0_c
+  method              <- object$args1$method
 
   if(!arm2){
     # Format treatment mean output
@@ -60,11 +61,22 @@ setMethod("summary", signature(object = "bdpnormal"), function(object){
                  sigma0_t, ", N0_t = ", N0_t))
       cat("\n")
       cat(paste0("Stochastic comparison (p_hat) - treatment (current vs. historical data): ",
-                 round(posterior_treatment$p_hat,4)))
-      cat("\n")
-      cat(paste0("Discount function value (alpha) - treatment: ",
-                 round(posterior_treatment$alpha_discount,4)))
+                 round(median(posterior_treatment$p_hat),4)))
       cat("\n")
+      if(method=="mc"){
+        alpha_summ <- quantile(posterior_treatment$alpha_discount,
+                               probs=c(0.5,0.025,0.975))
+
+        cat(paste0("Discount function value (alpha) - treatment: ",
+            round(alpha_summ[1],4),
+            " (95% CI: ",round(alpha_summ[2],4), ", ",round(alpha_summ[3],4),
+            ")"))
+        cat("\n")
+      } else{
+        cat(paste0("Discount function value (alpha) - treatment: ",
+            round(median(posterior_treatment$alpha_discount),4)))
+        cat("\n")
+      }
     }
     cat("95 percent confidence interval: \n")
     cat(paste0(" ",mean_CI_t))
@@ -99,26 +111,48 @@ setMethod("summary", signature(object = "bdpnormal"), function(object){
 
     if(!is.null(N0_t)){
       cat(paste0("Stochastic comparison (p_hat) - treatment (current vs. historical data): ",
-                 round(posterior_treatment$p_hat,4)))
+                 round(median(posterior_treatment$p_hat),4)))
       cat("\n")
     }
 
     if(!is.null(N0_c) & !is.null(N_c)){
       cat(paste0("Stochastic comparison (p_hat) - control (current vs. historical data): ",
-                 round(posterior_control$p_hat,4)))
+                 round(median(posterior_control$p_hat),4)))
       cat("\n")
     }
 
     if(!is.null(N0_t)){
-      cat(paste0("Discount function value (alpha) - treatment: ",
-                 round(posterior_treatment$alpha_discount,4)))
-      cat("\n")
+      if(method=="mc"){
+        alpha_summ <- quantile(posterior_treatment$alpha_discount,
+                               probs=c(0.5,0.025,0.975))
+
+        cat(paste0("Discount function value (alpha) - treatment: ",
+            round(alpha_summ[1],4),
+            " (95% CI: ",round(alpha_summ[2],4), ", ",round(alpha_summ[3],4),
+            ")"))
+        cat("\n")
+      } else{
+        cat(paste0("Discount function value (alpha) - treatment: ",
+            round(median(posterior_treatment$alpha_discount),4)))
+        cat("\n")
+      }
     }
 
     if(!is.null(N0_c) & !is.null(N_c)){
-      cat(paste0("Discount function value (alpha) - control: ",
-                 round(posterior_control$alpha_discount,4)))
-      cat("\n")
+      if(method=="mc"){
+        alpha_summ <- quantile(posterior_control$alpha_discount,
+                               probs=c(0.5,0.025,0.975))
+
+        cat(paste0("Discount function value (alpha) - control: ",
+            round(alpha_summ[1],4),
+            " (95% CI: ",round(alpha_summ[2],4), ", ",round(alpha_summ[3],4),
+            ")"))
+        cat("\n")
+      } else{
+        cat(paste0("Discount function value (alpha) - control: ",
+            round(median(posterior_control$alpha_discount),4)))
+        cat("\n")
+      }
     }
     cat("alternative hypothesis: ", ifelse(two_side, "two.sided", "one.sided"))
     cat("\n")
@@ -178,6 +212,8 @@ setMethod("summary", signature(object = "bdpbinomial"), function(object){
   N0_t                <- object$args1$N0_t
   y0_c                <- object$args1$y0_c
   N0_c                <- object$args1$N0_c
+  method              <- object$args1$method
+
 
   if(!arm2){
     ###Format treatment mean output
@@ -191,11 +227,23 @@ setMethod("summary", signature(object = "bdpbinomial"), function(object){
     if(!is.null(N0_t)){
       cat(paste0("Historical treatment data: ", y0_t, " and ", N0_t, "\n"))
       cat(paste0("Stochastic comparison (p_hat) - treatment (current vs. historical data): ",
-                 round(posterior_treatment$p_hat,4)))
-      cat("\n")
-      cat(paste0("Discount function value (alpha) - treatment: ",
-                 round(posterior_treatment$alpha_discount,4)))
+                 round(median(posterior_treatment$p_hat),4)))
       cat("\n")
+
+      if(method=="mc"){
+        alpha_summ <- quantile(posterior_treatment$alpha_discount,
+                               probs=c(0.5,0.025,0.975))
+
+        cat(paste0("Discount function value (alpha) - treatment: ",
+            round(alpha_summ[1],4),
+            " (95% CI: ",round(alpha_summ[2],4), ", ",round(alpha_summ[3],4),
+            ")"))
+        cat("\n")
+      } else{
+        cat(paste0("Discount function value (alpha) - treatment: ",
+            round(median(posterior_treatment$alpha_discount),4)))
+        cat("\n")
+      }
     }
     cat("95 percent confidence interval: \n")
     cat(paste0(" ",mean_CI_t))
@@ -238,27 +286,48 @@ setMethod("summary", signature(object = "bdpbinomial"), function(object){
     if(!is.null(N0_c)){
       cat(paste0("Historical control data: ", y0_c, " and ", N0_c, "\n"))
     }
+
+
     if(!is.null(N_t) & !is.null(N0_t)){
       cat(paste0("Stochastic comparison (p_hat) - treatment (current vs. historical data): ",
-                 round(posterior_treatment$p_hat,4)))
+                 round(median(posterior_treatment$p_hat),4)))
       cat("\n")
+
+      if(method=="mc"){
+        alpha_summ <- quantile(posterior_treatment$alpha_discount,
+                               probs=c(0.5,0.025,0.975))
+
+        cat(paste0("Discount function value (alpha) - treatment: ",
+            round(alpha_summ[1],4),
+            " (95% CI: ",round(alpha_summ[2],4), ", ",round(alpha_summ[3],4),
+            ")"))
+        cat("\n")
+      } else{
+        cat(paste0("Discount function value (alpha) - treatment: ",
+            round(median(posterior_treatment$alpha_discount),4)))
+        cat("\n")
+      }
     }
+
     if(!is.null(N_c) & !is.null(N0_c)){
       cat(paste0("Stochastic comparison (p_hat) - control (current vs. historical data): ",
-                 round(posterior_control$p_hat,4)))
+                 round(median(posterior_control$p_hat),4)))
       cat("\n")
-    }
 
-    if(!is.null(N_t) & !is.null(N0_t)){
-      cat(paste0("Discount function value (alpha) - treatment: ",
-                 round(posterior_treatment$alpha_discount,4)))
-      cat("\n")
-    }
+      if(method=="mc"){
+        alpha_summ <- quantile(posterior_control$alpha_discount,
+                               probs=c(0.5,0.025,0.975))
 
-    if(!is.null(N_c) & !is.null(N0_c)){
-      cat(paste0("Discount function value (alpha) - control: ",
-                 round(posterior_control$alpha_discount,4)))
-      cat("\n")
+        cat(paste0("Discount function value (alpha) - control: ",
+            round(alpha_summ[1],4),
+            " (95% CI: ",round(alpha_summ[2],4), ", ",round(alpha_summ[3],4),
+            ")"))
+        cat("\n")
+      } else{
+        cat(paste0("Discount function value (alpha) - control: ",
+            round(median(posterior_control$alpha_discount),4)))
+        cat("\n")
+      }
     }
 
     cat("alternative hypothesis: ", ifelse(two_side, "two.sided", "one.sided"))
@@ -312,6 +381,7 @@ setMethod("summary", signature(object = "bdpsurvival"), function(object){
   data                <- args1$data
   breaks              <- args1$breaks
   arm2                <- args1$arm2
+  method              <- args1$method
 
   historical <- NULL
   treatment  <- NULL
@@ -349,11 +419,23 @@ setMethod("summary", signature(object = "bdpsurvival"), function(object){
       print(m_t)
     } else{
       cat(paste0("Stochastic comparison (p_hat) - treatment (current vs. historical data): ",
-                 round(posterior_treatment$p_hat,4)))
-      cat("\n")
-      cat(paste0("Discount function value (alpha) - treatment: ",
-                 round(posterior_treatment$alpha_discount,4)))
+                 round(median(posterior_treatment$p_hat),4)))
       cat("\n")
+      if(method=="mc"){
+        alpha_summ <- quantile(posterior_treatment$alpha_discount,
+                               probs=c(0.5,0.025,0.975))
+
+        cat(paste0("Discount function value (alpha) - treatment: ",
+            round(alpha_summ[1],4),
+            " (95% CI: ",round(alpha_summ[2],4), ", ",round(alpha_summ[3],4),
+            ")"))
+        cat("\n")
+      } else{
+        cat(paste0("Discount function value (alpha) - treatment: ",
+            round(median(posterior_treatment$alpha_discount),4)))
+        cat("\n")
+      }
+
       cat("\n")
       cat("Current treatment - augmented posterior summary:")
       cat("\n")
@@ -410,35 +492,53 @@ setMethod("summary", signature(object = "bdpsurvival"), function(object){
 
     if(!is.null(args1$S0_t)){
       cat(paste0("Stochastic comparison (p_hat) - treatment (current vs. historical data): ",
-                 round(posterior_treatment$p_hat,4)))
+                 round(median(posterior_treatment$p_hat),4)))
       cat("\n")
     }
 
     if(!is.null(args1$S0_c) & !is.null(args1$S_c)){
       cat(paste0("Stochastic comparison (p_hat) - control (current vs. historical data): ",
-                 round(posterior_control$p_hat,4)))
+                 round(median(posterior_control$p_hat),4)))
       cat("\n")
     }
 
     if(!is.null(args1$S0_t)){
-      cat(paste0("Discount function value (alpha) - treatment: ",
-                 round(posterior_treatment$alpha_discount,4)))
-      cat("\n")
+      if(method=="mc"){
+        alpha_summ <- quantile(posterior_treatment$alpha_discount,
+                               probs=c(0.5,0.025,0.975))
+
+        cat(paste0("Discount function value (alpha) - treatment: ",
+            round(alpha_summ[1],4),
+            " (95% CI: ",round(alpha_summ[2],4), ", ",round(alpha_summ[3],4),
+            ")"))
+        cat("\n")
+      } else{
+        cat(paste0("Discount function value (alpha) - treatment: ",
+            round(median(posterior_treatment$alpha_discount),4)))
+        cat("\n")
+      }
     }
 
     if(!is.null(args1$S0_c) & !is.null(args1$S_c)){
-      cat(paste0("Discount function value (alpha) - control: ",
-                 round(posterior_control$alpha_discount,4)))
-      cat("\n")
+      if(method=="mc"){
+        alpha_summ <- quantile(posterior_control$alpha_discount,
+                               probs=c(0.5,0.025,0.975))
+
+        cat(paste0("Discount function value (alpha) - control: ",
+            round(alpha_summ[1],4),
+            " (95% CI: ",round(alpha_summ[2],4), ", ",round(alpha_summ[3],4),
+            ")"))
+        cat("\n")
+      } else{
+        cat(paste0("Discount function value (alpha) - control: ",
+            round(median(posterior_control$alpha_discount),4)))
+        cat("\n")
+      }
     }
     cat("\n")
     print(summ_table)
 
   }
-
-
-
-
 })
 
 # Helper functions:
@@ -448,3 +548,45 @@ pp <- function(m){
               row.names=T, col.names=F, quote=F)
 }
 
+
+#' @title bdpregression Object Summary
+#' @description \code{summary} method for class \code{bdpregression}.
+#' @param object object of class \code{bdpregression}. The result of a call to the
+#'   \code{\link{bdpregression}} function.
+#'
+#' @details Displays a summary of the \code{bdpregression} fit including the
+#'   input data, the stochastic comparison between current and historical
+#'   data, and the resulting historical data weight (alpha). If historical
+#'   data is missing then no stochastic comparison nor weight are displayed.
+#'
+#'   ...
+#'
+#' @import methods
+#' @importFrom utils head
+#' @importFrom utils write.table
+#' @export
+setMethod("summary", signature(object = "bdpregression"), function(object){
+
+
+  posterior_treatment <- object$posterior_treatment
+  posterior_control   <- object$posterior_control
+  arm2                <- object$args1$arm2
+
+  if(!arm2){
+    summ <- summary(posterior_treatment$posterior_regression)
+
+    cat("One-armed bdp regression")
+    cat("\n")
+    print(summ)
+
+    if(!is.null(posterior_treatment$p_hat)){
+      cat(paste0("Stochastic comparison (p_hat) - treatment (current vs. historical data): ",
+                 round(posterior_treatment$p_hat,4)))
+      cat("\n")
+      cat(paste0("Discount function value (alpha) - treatment: ",
+                 round(posterior_treatment$alpha_discount,4)))
+    }
+  }
+
+})
+
