@@ -1,14 +1,9 @@
 
 #include <R.h>
 #include <Rinternals.h>
-#include <stdlib.h> // for NULL
+#include <stdlib.h>
 #include <R_ext/Rdynload.h>
 
-/* FIXME:
- Check these declarations against the C/Fortran source code.
- */
-
-/* .Call calls */
 extern SEXP bayesDP_ppexpM(SEXP, SEXP, SEXP);
 extern SEXP bayesDP_ppexpV(SEXP, SEXP, SEXP);
 
